Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(338)

Unified Diff: headless/public/headless_browser.h

Issue 1858403003: headless: Require the user to pass in an initial URL (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: headless/public/headless_browser.h
diff --git a/headless/public/headless_browser.h b/headless/public/headless_browser.h
index 75394078f87d3fb90d170d7acf69a5c9fb60fa0d..367a8384fec3957b274be81238ed40eaeebc4927 100644
--- a/headless/public/headless_browser.h
+++ b/headless/public/headless_browser.h
@@ -35,8 +35,10 @@ class HEADLESS_EXPORT HeadlessBrowser {
public:
struct Options;
// Create a new browser tab. |size| is in physical pixels.
virtual std::unique_ptr<HeadlessWebContents> CreateWebContents(
+ const GURL& initial_url,
const gfx::Size& size) = 0;
// Returns a task runner for submitting work to the browser main thread.
@@ -35,8 +35,10 @@ class HEADLESS_EXPORT HeadlessBrowser {
public:
struct Options;
- // Create a new browser tab. |size| is in physical pixels.
+ // Create a new browser tab which navigates to |initial_url|. |size| is in
+ // physical pixels.
virtual std::unique_ptr<HeadlessWebContents> CreateWebContents(

Powered by Google App Engine
This is Rietveld 408576698